package com.jiuqi.db.impl;

import com.jiuqi.db.DBFunction;
import java.util.List;
import java.sql.DatabaseMetaData;
import java.sql.SQLException;
import com.jiuqi.db.DBMetaData;

public class DB2DBMetaData implements DBMetaData
{
    private static final String LeftParenthesis = "(";
    private static final String RightParenthesis = ")";
    private static final String comma = ",";
    private static final String IsNull = " ";
    private static final String NotNull = "not null";
    private static final String space = " ";
    private static final String DEF = " default ";
    private static final String BIT = "NUMERIC(1)";
    private static final String TINYINT = "INTEGER";
    private static final String SMALLINT = "SMALLINT";
    private static final String INTEGER = "INTEGER";
    private static final String BIGINT = "BIGINT";
    private static final String FLOAT = "FLOAT";
    private static final String REAL = "REAL";
    private static final String DOUBLE = "DOUBLE";
    private static final String NUMERIC = "NUMERIC";
    private static final String DECIMAL = "DECIMAL";
    private static final String CHAR = "CHAR";
    private static final String VARCHAR = "VARCHAR";
    private static final String LONGVARCHAR = "LONG VARCHAR";
    private static final String TIMESTAMP = "TIMESTAMP";
    private static final String VARBINARY = "LONG VARCHAR FOR BIT DATA";
    private static final String LONGVARBINARY = "BLOB(100M)";
    private static final String BLOB = "BLOB(100M)";
    private static final String CLOB = "CLOB";
    private int maxColumnCount;
    private int maxRecordSize;
    
    private void raise(final String msg) throws SQLException {
        throw new SQLException(msg);
    }
    
    public DB2DBMetaData(final DatabaseMetaData metaData) throws SQLException {
        this.maxColumnCount = metaData.getMaxColumnsInTable();
        this.maxRecordSize = 8000;
    }
    
    public int databaseType() {
        return 3;
    }
    
    public int maxColumnCount() {
        return this.maxColumnCount;
    }
    
    public int maxRecordSize() {
        return this.maxRecordSize;
    }
    
    public int maxIndexNameLength() {
        return 18;
    }
    
    public int maxFieldNameLength() {
        return 20;
    }
    
    public int maxTableNameLength() {
        return 20;
    }
    
    public int maxColumnByteSize(final int sqlType) throws SQLException {
        int result = 0;
        switch (sqlType) {
            case -7: {
                result = 5;
                break;
            }
            case -6: {
                result = 10;
                break;
            }
            case 5: {
                result = 5;
                break;
            }
            case 4: {
                result = 4;
                break;
            }
            case -5: {
                result = 8;
                break;
            }
            case 6: {
                result = 8;
                break;
            }
            case 7: {
                result = 4;
                break;
            }
            case 2: {
                result = 17;
                break;
            }
            case 3: {
                result = 17;
                break;
            }
            case 1: {
                result = -1;
                break;
            }
            case 12: {
                result = -1;
                break;
            }
            case -1: {
                result = 16;
                break;
            }
            case 93: {
                result = 8;
                break;
            }
            case -2: {
                result = -1;
                break;
            }
            case -3: {
                result = -1;
                break;
            }
            case -4: {
                result = 16;
                break;
            }
            case 2004: {
                result = 16;
                break;
            }
            case 2005: {
                result = 16;
                break;
            }
        }
        if (result == 0) {
            this.raise("不支持的数据类型 " + Integer.toString(sqlType));
        }
        return result;
    }
    
    public String getDropFieldPreSql(final String tableName, final String fieldName) {
        return null;
    }
    
    public String getDropFieldDDL(final String tableName, final String fieldName) {
        return "alter table " + tableName + " drop column " + fieldName;
    }
    
    public String getFieldDDL(final int sqlType, final int size, final int scale, final boolean isNull, final String defValue) throws SQLException {
        final StringBuffer result = new StringBuffer();
        switch (sqlType) {
            case -7: {
                result.append("NUMERIC(1)");
                break;
            }
            case -6: {
                result.append("INTEGER");
                break;
            }
            case 5: {
                result.append("SMALLINT");
                break;
            }
            case 4: {
                result.append("INTEGER");
                break;
            }
            case -5: {
                result.append("BIGINT");
                break;
            }
            case 6: {
                result.append("FLOAT");
                break;
            }
            case 7: {
                result.append("REAL");
                break;
            }
            case 8: {
                result.append("DOUBLE");
                break;
            }
            case 2: {
                if (size < 0 || size > 31 || scale < 0 || scale > 31) {
                    this.raise("精度或小数位定义错误");
                }
                result.append("NUMERIC");
                result.append("(");
                result.append(size);
                result.append(",");
                result.append(scale);
                result.append(")");
                break;
            }
            case 3: {
                if (size < 0 || size > 31 || scale < 0 || scale > 31) {
                    this.raise("精度或小数位定义错误");
                }
                result.append("DECIMAL");
                result.append("(");
                result.append(size);
                result.append(",");
                result.append(scale);
                result.append(")");
                break;
            }
            case 1: {
                if (size > 254 || size <= 0) {
                    this.raise("长度定义错误应在1~254之间");
                }
                result.append("CHAR");
                result.append("(");
                result.append(size);
                result.append(")");
                break;
            }
            case 12: {
                if (size > 32672 || size <= 0) {
                    this.raise("长度定义错误应在1~32672之间");
                }
                result.append("VARCHAR");
                result.append("(");
                result.append(size);
                result.append(")");
                break;
            }
            case -1: {
                result.append("LONG VARCHAR");
                break;
            }
            case 91:
            case 92:
            case 93: {
                result.append("TIMESTAMP");
                break;
            }
            case -3:
            case -2: {
                if (size > 32700 || size <= 0) {
                    this.raise("长度定义错误应在1~32700之间");
                }
                result.append("LONG VARCHAR FOR BIT DATA");
                result.append("(");
                result.append(size);
                result.append(")");
                break;
            }
            case -4: {
                result.append("BLOB(100M)");
                break;
            }
            case 2004: {
                result.append("BLOB(100M)");
                break;
            }
            case 2005: {
                result.append("CLOB");
                break;
            }
        }
        if (result.length() == 0) {
            this.raise("不支持的数据类型");
        }
        result.append(" ");
        result.append(isNull ? " " : "not null");
        result.append(" ");
        if (defValue != null && !defValue.equals("")) {
            result.append(" default ");
            result.append(defValue);
        }
        return result.toString();
    }
    
    public boolean getModifyFieldSqls(final String tableName, final String sFieldName, final int sSqlType, final int sSize, final int sScale, final boolean sIsNull, final String sDefValue, final String dFieldName, final int dSqlType, final int dSize, final int dScale, final boolean dIsNull, final String dDefValue, final List sqls) throws SQLException {
        return false;
    }
    
    public boolean getDDLCausesTransactionCommit() {
        return false;
    }
    
    public boolean getDDLIgnoredInTransactions() {
        return false;
    }
    
    public String getDefaultScheme() {
        return null;
    }
    
    public boolean getSupportDropColumn() {
        return false;
    }
    
    public DBFunction createDBFunction() {
        return new DB2DBFunction();
    }
    
    public boolean getTruncateNumber() {
        return true;
    }
}
